@@ -9,7 +9,7 @@
 
 #include "Runners.h"
 
-#include <utils/CalamaresUtilsSystem.h>
+#include <utils/System.h>
 #include <utils/Logger.h>
 
 #include <QFileInfo>
