@@ -23,7 +23,9 @@ public:
     {
         None,  /// << Invalid
         FSArchive,
+        FSArchiveFS,
         Squashfs,
+        Tarball,
     };
 
     explicit UnpackFSCJob( QObject* parent = nullptr );
